# -*- coding: utf-8 -*-
#
# Copyright 2012 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Darwin-specific GUI event handling code."""

from PyQt4 import QtGui
from twisted.internet.defer import inlineCallbacks

from ubuntuone.platform.tools import SyncDaemonTool

from ubuntuone.controlpanel.gui.qt.main import twisted_main


@inlineCallbacks
def handle_cmd_q(app, event):
    """Handle the quit event on darwin."""
    # pylint: disable=W0702
    try:
        st = SyncDaemonTool()
        yield st.quit()
    except:
        pass
    twisted_main.main_quit(app)
    app.aboutToQuit.emit()


def install_platform_event_handlers(app):
    """Add code to catch cmd-Q."""
    # on darwin, a menu item with 'quit' in its title is moved to
    # the application menu and given the cmd-Q shortcut by Qt. If
    # we don't provide one, Qt will give us one that just calls
    # QApplication::quit(), which doesn't quit syncdaemon and
    # causes problems with the qtreactor.

    # QMenuBar with no parent gives us an app-wide menu bar.
    # Note that Qt does not make this a singleton, though, so we have
    # to keep it around.
    menubar = QtGui.QMenuBar(None)

    quit_action = QtGui.QAction("quit", menubar,
                                triggered=lambda x:
                                handle_cmd_q(app, x))
    quit_action.setObjectName("darwin-cmd-q")
    menu = menubar.addMenu("This string is not used.")
    menu.addAction(quit_action)

    return menubar
