# -*- coding: utf-8 -*-
#
# Copyright 2012 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Tests for darwin-specific parts of control panel's Qt main."""

from PyQt4 import QtGui

from twisted.internet.defer import (inlineCallbacks, succeed)

from ubuntuone.controlpanel.gui.qt import main
from ubuntuone.controlpanel.tests import TestCase
from ubuntuone.controlpanel.gui.tests import FakeSignal


class FakeApplication(object):
    """Fake Application with quit signal."""
    def __init__(self):
        """Set up fake signal."""
        # pylint: disable=C0103
        self.aboutToQuit = FakeSignal()
        self.aboutToQuit.connect(self.record_call)
        self.signal_called = None

    def record_call(self, *args):
        """record call"""
        self.signal_called = args


class FakeSDTool(object):
    """Fake tool."""
    called = False

    def quit(self):
        """Quit successfully."""
        FakeSDTool.called = True
        return succeed(None)


class FakeSDToolRaising(object):
    """Fake tool that raises."""
    shouldRaise = False
    called = False

    def quit(self):
        """Raise."""
        self.called = True
        raise Exception("exception")


class QuitTestCase(TestCase):
    """Test quit event handling."""

    @inlineCallbacks
    def setUp(self):
        """Set up common fakes."""
        yield super(QuitTestCase, self).setUp()
        self.fake_app = FakeApplication()
        self.patch(main.darwin.twisted_main, 'main_quit',
                   self._set_called)

    @inlineCallbacks
    def test_cmd_q_func_quits_sd(self):
        """Test that we call syncdaemontool.quit """
        self.patch(main.darwin, 'SyncDaemonTool', FakeSDTool)

        yield main.darwin.handle_cmd_q(self.fake_app, None)
        self.assertEqual(FakeSDTool.called, True)

    @inlineCallbacks
    def test_cmd_q_func_ignores_exception(self):
        """Test that we keep going when SDT raises."""
        self.patch(main.darwin, 'SyncDaemonTool', FakeSDToolRaising)

        yield main.darwin.handle_cmd_q(self.fake_app, None)
        self.assertEqual(self._called, ((self.fake_app,), {}))

        self.assertEqual(self.fake_app.signal_called, ())


class InstallEventHandlersTestCase(TestCase):
    """Test creating Qt menu items."""

    def test_install_handlers_creates_action(self):
        """Test menu items created"""
        self.patch(main.darwin, 'handle_cmd_q',
                   self._set_called)
        app = QtGui.QApplication.instance()
        menubar = main.darwin.install_platform_event_handlers(app)
        quit_action = menubar.findChild(QtGui.QAction, "darwin-cmd-q")
        quit_action.trigger()
        self.assertEqual(self._called, ((app, False), {}))
